@@ -1,36 +1,16 @@
-// utilsmod.rs
-//! Often used common utility fn.
+//! utilsmod.rs
+
+//use lazy_static::lazy_static;
+//use regex::Regex;
 use unwrap::unwrap;
 
 use std::{fs, io, path::Path};
-
-/// Traverse dir and its sub-dir, but avoid excluded dirs.
-/// The find_file and the exclude dir strings must start with /.
-///
-/// ## Example
-///
-/// ```
-/// use std::path::Path;
-/// use lmake_lines_of_code::*;
-///
-/// let files = traverse_dir_with_exclude_dir(
-///     Path::new("/home/project/src"),
-///     "/*.rs",
-///     // avoid big folders and other folders with *.crev
-///     &vec![
-///         "/.git".to_string(),
-///         "/target".to_string(),
-///         "/docs".to_string()
-///     ]
-/// ).unwrap();
-/// for rs_file_name in files.iter() {
-///     println!("{}", &rs_file_name);
-/// }
-/// ```
+/// traverse dir (sub-dir) with exclude dir
+/// the find_file and the exclude dir strings must start with /
 pub fn traverse_dir_with_exclude_dir(
     dir: &Path,
     find_file: &str,
-    exclude_dirs: &[String],
+    exclude_dirs: &Vec<String>,
 ) -> io::Result<Vec<String>> {
     // if the parameter is /*.rs, I can eliminate /*
     let find_file = &find_file.replace("/*", "");
@@ -53,8 +33,10 @@ pub fn traverse_dir_with_exclude_dir(
                     let mut sub_v = traverse_dir_with_exclude_dir(&path, find_file, exclude_dirs)?;
                     v.append(&mut sub_v);
                 }
-            } else if str_path.ends_with(find_file) {
-                v.push(str_path.to_string());
+            } else {
+                if str_path.ends_with(find_file) {
+                    v.push(str_path.to_string());
+                }
             }
         }
     }
